#!/bin/bash

die() { echo "ERROR: $@"; exit 1; }

for argv in $*
do
	case $1 in
		--ip=*) ip="${1##*=}" ;;
		--port=*) port="${1##*=}" ;;
		--fingerprint=*) fingerprint="${1##*=}" ;;
		--command=*) command="${1##*=}" ;;
	esac
	shift
done

# sanity checks
[ -x $(type -P nssl) ] || die "nssl not found"
[[ -n ${ip} ]] || die "no ip given"
[[ -n ${port} ]] || die "no port given"
[[ -n ${fingerprint} ]] || die "no fingerprint given"
[[ -n ${command} ]] || die "no command given"

nssl "${ip}" "${port}" << EOF
certauth "${fingerprint}"
${command}
quit
EOF

